@@ -26,8 +26,7 @@
 package Crypt::PKCS11;
 
 use 5.008000;
-use strict;
-use warnings;
+use common::sense;
 use Carp;
 
 use constant CRYPTOKI_VERSION_MAJOR => 2;
@@ -1387,7 +1386,7 @@ our %CKZ_NAME = (
     CKZ_SALT_SPECIFIED() => 'CKZ_SALT_SPECIFIED',
 );
 
-our $VERSION = '0.99_01';
+our $VERSION = '0.99_02';
 
 our (@ISA, %EXPORT_TAGS, @EXPORT_OK);
 BEGIN {
